;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "prescient" "20250816.19"
  "Better sorting and filtering."
  '((emacs "25.1"))
  :url "https://github.com/raxod502/prescient.el"
  :commit "87e2d2f2ddf24f591a5f70cc90d2afb4537caa18"
  :revdesc "87e2d2f2ddf2"
  :keywords '("extensions")
  :authors '(("Radian LLC" . "contact+prescient@radian.codes"))
  :maintainers '(("Radian LLC" . "contact+prescient@radian.codes")))
